//#define XERR
#include "error.ih"

    // line nrs 0 are not shown

ostream &Error::operator()(ConfigSrc type, uint16_t lineNr, Err value)
{
    cerr << "[Error " << src(type);

    if (lineNr != 0)
        cerr << ' ' << lineNr;

    return cerr << "] " << s_errorMsg[value];
}
